/*******************************************************************
********************************************************************
****								****
****    File:  		st80fileview.c				****
****	usage: 		st80fileview <filename>			****
****								****
****    Author:		Hubert Baumeister			****
**** 	Date created:	8.2.92					****
****								****
****	Address:	Hubert Baumeister			****
****			MPI Informatik				****
****			Im Stadtwald				****
****		 W-6600 Saarbr"ucken				****
****			Germany					****
****	Phone: 		(x49-681)302-5432			****
****	e-mail: 	Hubert.Baumeister@mpi-sb.mpg.de		****
****								****
****		(c) '92 Hubert Baumeister			****
****								****
********************************************************************
********************************************************************
****								****
****    st80fileview connects to a Unix domain server		****
****    socket named $HOME/.st80fileviewskt on the same		****
****    computer and sends its argument over the socket		****
****    after it has completed its path.  For example		****
****    'st80fileview test.tex' will send 			****
****    /home/usr/hubert/test.tex to the process listening	****
****    on the socket.						****
****								****
****    If there is no such socket or if no process is		****
****    waiting for a connection on this socket an error	****
****    message is printed.					****
****								****
****    Note that using Unix domain sockets the server		****
****    process and st80fileview have to run on the same	****
****    computer. It is not sufficient that both processes	****
****    have access to the same $HOME/.st80fileviewskt.		****
****								****
********************************************************************
*******************************************************************/

#include <sys/types.h>
#include <sys/socket.h>
#include <sys/un.h>
#include <sys/param.h>
#include <stdlib.h>

main(argc,argv)
 int argc;
 char **argv;
{
  int skt;
  char *buf;
  char fullpath[MAXPATHLEN];
  struct sockaddr_un sktaddr;
  char sockpath[MAXPATHLEN];
  char *home;

  if(argc < 2 || argc > 2) {
    printf("Usage: st80fileview <filename>\n");
    exit(1);
  };

  home = getenv("HOME");
  if(home == (char *)0) {
    printf("st80fileview: Can't get environment variable HOME\n");
    exit(1);
  }

  *sockpath = '\0';
  strcat(sockpath,home);
  strcat(sockpath,"/");
  strcat(sockpath,".st80fileviewskt");
  
  skt = socket(AF_UNIX,SOCK_STREAM,0);

  if(skt < 0) {
    perror("st80fileview: socket");
    exit(1);
  }

  sktaddr.sun_family = AF_UNIX;
  bcopy(sockpath,sktaddr.sun_path,strlen(sockpath));

  if(connect(skt,sktaddr,sizeof(sktaddr)) < 0) {;
    perror("st80fileview: connect");
    close(skt);
    exit(1);
  };

  if(realpath(argv[1],fullpath) == 0) {
    perror("st80fileview: realpath");
    exit(1);
  }
  write(skt,fullpath,strlen(fullpath));
  close(skt);
  
}
